#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.28
visibility:           public
id:                   quic-0.1.28-D8PgH7KgVZOLx6z6y3h34a
key:                  quic-0.1.28-D8PgH7KgVZOLx6z6y3h34a
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  b3420459915b030f91733fcf4de8fecc
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Info
    Network.QUIC.Types.Integer Network.QUIC.Types.Packet
    Network.QUIC.Types.Queue Network.QUIC.Types.Resumption
    Network.QUIC.Types.Time Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/quic-0.1.28
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quic-0.1.28
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quic-0.1.28
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.28-D8PgH7KgVZOLx6z6y3h34a
depends:
    array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-HKNPUjeO8LQ9RSeGAokMwf
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.2-3Ok1vjJBlZbIavxoQy1Tnc
    crypton-1.0.5-1z1P9gki3DpXKZxddhNPM
    crypton-x509-1.7.7-IcedmXM2ULtCeEKBmI6smS
    crypton-x509-system-1.6.8-2KfDuRCGviS3EE9AkOJzsR
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    fast-logger-3.2.4-9MkiYHFfcN0J1h5a4hmpPz filepath-1.4.300.1
    iproute-1.7.15-71jlcPG6yHXLNE9dstbffw
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-946StwFfSrELqUahTPYWqr
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
    network-control-0.1.4-qLZWvppgeBCvGssIiX9MG
    network-udp-0.0.0-DGoAowmF9z0E0E6zwu93Hr
    random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    serialise-0.2.6.1-L0qWanfuTgS86ogXg4R9At stm-2.5.1.0
    tls-2.0.6-7WmlfPARP3RJVtiKAGpOLl
    unix-time-0.4.17-5iWAXUUOglQ2wMYsjqHDSJ
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

